Odds

Enum Odds 

pub enum Odds {
    American(i32),
    Decimal(Decimal),
    Fractional {
        num: u32,
        den: u32,
    },
}

Variants



American(i32)



Decimal(Decimal)



Fractional

Fields

num: u32
den: u32

Implementations

Source

impl Odds

pub fn to_american(&self) -> Result<i32, ConversionError>

Convert from decimal or fractional to american using default parameters. If already american, just return the value.

pub fn to_american_custom( &self, config: &ConversionConfig, ) -> Result<i32, ConversionError>

Convert from decimal or fractional to american using custom parameters. If already american, just return the value.

pub fn to_fractional(&self) -> Result<(u32, u32), ConversionError>

Convert from american or decimal to fractional using default parameters. If already fractional, just return the value.

pub fn to_fractional_custom( &self, config: &ConversionConfig, ) -> Result<(u32, u32), ConversionError>

Convert from american or decimal to fractional using custom parameters. If already fractional, just return the value.

pub fn to_decimal(&self) -> Result<Decimal, ConversionError>

Convert from american or fractional to decimal using default parameters. If already decimal, just return the value.

pub fn to_decimal_custom( &self, config: &ConversionConfig, ) -> Result<Decimal, ConversionError>

Convert from american or fractional to decimal using custom parameters. If already decimal, just return the value.

pub fn to_fractional_str(&self) -> Result<String, ConversionError>

Convert from american or decimal to fractional using default parameters (if already fractional, just take the value) and format to string.

pub fn to_fractional_str_custom( &self, config: &ConversionConfig, ) -> Result<String, ConversionError>

Convert from american or decimal to fractional using custom parameters (if already fractional, just take the value) and format to string.

pub fn to_decimal_str(&self) -> Result<String, ConversionError>

Convert from american or fractional to decimal using default parameters (if already decimal, just take the value) and format to string.

pub fn to_decimal_str_custom( &self, config: &ConversionConfig, ) -> Result<String, ConversionError>

Convert from american or fractional to decimal using custom parameters (if already decimal, just take the value) and format to string.